@@ -21,11 +21,7 @@ public:
     ~LineChartMaterial();
 
     QSGMaterialType *type() const override;
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-    QSGMaterialShader *createShader() const override;
-#else
     QSGMaterialShader *createShader(QSGRendererInterface::RenderMode) const override;
-#endif
     int compare(const QSGMaterial *other) const override;
 
     float aspect = 1.0;
@@ -39,21 +35,7 @@ public:
     LineChartShader();
     ~LineChartShader();
 
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-    char const *const *attributeNames() const override;
-
-    void initialize() override;
-    void updateState(const RenderState &state, QSGMaterial *newMaterial, QSGMaterial *oldMaterial) override;
-
-private:
-    int m_matrixLocation = 0;
-    int m_opacityLocation = 0;
-    int m_lineWidthLocation = 0;
-    int m_aspectLocation = 0;
-    int m_smoothingLocation = 0;
-#else
     bool updateUniformData(QSGMaterialShader::RenderState &state, QSGMaterial *newMaterial, QSGMaterial *oldMaterial) override;
-#endif
 };
 
 #endif // LINECHARTMATERIAL_H
